@@ -21,17 +21,18 @@ add_gloss <- function(glosses){
   glosses <- glosses[glosses != ""]
 
 # remove formatting --------------------------------------------------------
-  glosses2add <- gsub("[_\\*].*[_\\*]", "", glosses[glosses == toupper(glosses)])
+  glosses2add <- gsub("[_\\*]", "", glosses[glosses == toupper(glosses)])
   without_escape <- which(!(grepl("^\\{", glosses2add) &
                                grepl("\\}$", glosses2add)))
   glosses2add <- glosses2add[without_escape]
 
 # add glosses to the list --------------------------------------------------
-  utils::write.table(x = glosses2add,
-                     file = getOption("lingglosses.glosses_list"),
-                     row.names = FALSE, col.names = FALSE, append = TRUE,
-                     fileEncoding = "UTF-8")
-
+  if(length(glosses2add) > 0){
+    utils::write.table(x = glosses2add,
+                       file = getOption("lingglosses.glosses_list"),
+                       row.names = FALSE, col.names = FALSE, append = TRUE,
+                       fileEncoding = "UTF-8")
+  }
 # add small caps -----------------------------------------------------------
   glosses <- ifelse(glosses == toupper(glosses) &
                       !(grepl("^\\{", glosses) & grepl("\\}$", glosses)),
